@@ -143,7 +143,7 @@ class SortedSet(object):
         with self.lock:
             items = [self._pop_item() for __ in range(min(num, len(self)))]
 
-        return filter(lambda i: i != None, items)
+        return filter(lambda i: i is not None, items)
 
     def clear(self):
         """
@@ -211,8 +211,6 @@ class SortedSet(object):
         if not results:
             raise KeyError("%s is empty" % self.name)
 
-        with open('foo.txt', 'a') as f:
-            f.write(str(results) + '\n')
         return results[0]
 
     def _pop_item(self):
@@ -260,11 +258,11 @@ class SortedSet(object):
 
         """
         try:
-            self.serializer.load
+            self.serializer.loads
         except AttributeError:
             return item
 
-        return self.serializer.load(item)
+        return self.serializer.loads(item)
 
     def _dump_item(self, item):
         """
@@ -272,11 +270,11 @@ class SortedSet(object):
 
         """
         try:
-            self.serializer.dump
+            self.serializer.dumps
         except AttributeError:
             return item
 
-        return self.serializer.dump(item)
+        return self.serializer.dumps(item)
 
 
 class TimeSortedSet(SortedSet):
@@ -302,12 +300,8 @@ class TimeSortedSet(SortedSet):
 
 class _DefaultSerializer(Serializer):
 
-    def load(self, str_from_redis):
-        return str_from_redis
-
-    def dump(self, obj):
-        return obj
+    loads = str
+    dumps = lambda self, i: i
 
 
 _default_scorer = lambda i: 0
-
